% -------------------------------------------------------------------------
%  Filename BSCALLvsS.m
%  Black-Scholes Call Option Price vs Undrlying Asset
%  Programmed by CBS
% -------------------------------------------------------------------------
clear all, close all, clf 
K = 50;
r = 0.06;
sigma = 0.3;
tau = 0.4;
%
dS = K/400;
St = 200*dS:dS:600*dS;
d1 = (log(St/K)+(r + sigma*sigma/2).*tau)/sigma./sqrt(tau);
d2 = d1 - sigma.*sqrt(tau);
Ct = St.*normcdf(d1,0,1) - K*exp(-r.*tau).*normcdf(d2,0,1);
Payoff = max(St-K,0);
yK = 0:0.02:4.3;
A = 60;
yA1 = 0:0.03:9.8; yA2 = 9.8:0.001:12;
Stdum = 60:0.05:75;
yStdum1 = 12;
yStdum2 = 9.9;
hold on
plot(St,Ct,'k',St,Payoff,'k-.','LineWidth',2.5)
legend('\bf Call Option Price','\bf Payoff',2)
ylabel('Call Option Price','Fontsize',12','Fontweigh','bold');
axis([25,75, 0, 30 ])
% About tick
set(gca,'fontsize',11,'fontweigh','bold')
plot(K,yK,'k',A,yA1,'k',A,yA2,'k',Stdum,yStdum1,'k',Stdum,yStdum2,'k')
text(76,0,'\bf\it S_t','Fontsize',12')
text(38,-2.5,'\bf OTM','Fontsize',12')
text(48,-2.5,'\bf ATM','Fontsize',12')
text(58,-2.5,'\bf ITM','Fontsize',12')
text(48,1.0,'\it K','Fontsize',12','Fontweigh','bold')
text(61.5,11,'\bf Time Value','Fontsize',12'), 
text(61.5,4,'\bf Intrinsic Value','Fontsize',12')
% title('\bf Underlying and Call Option Price','Fontsize',14,'Fontweigh','bold')
hold off
% End of program
% -------------------------------------------------------------------------