% -------------------------------------------------------------------------
%  Filename: BlackScholesCall3D.m
%  3-D Graphs of Black-Scholes Call Option Price
%  Programmed by CBS
% -------------------------------------------------------------------------
clear all, close all, clf;
K = 50;
r = 0.06;
sigma = 0.3;
Tmax = 1;
dt = Tmax/20; dS = K/20;
xSt = 10*dS:dS:30*dS; 
ytau = dt:dt:20*dt;
[St,tau] = meshgrid(xSt,ytau);
d1 = (log(St/K)+(r + sigma*sigma/2).*tau)/sigma./sqrt(tau);
d2 = d1 - sigma.*sqrt(tau);
Ct = St.*normcdf(d1,0,1) - K*exp(-r.*tau).*normcdf(d2,0,1);
Pt = Ct + K*exp(-r.*tau) - St;
% makegray = gray(7); colormap(makegray);
surf(St,tau,Ct)
set(gca,'fontsize',11,'fontweigh','bold')
xlabel('\it S_t','fontsize',12,'fontweigh','bold')
ylabel('\it \tau = T-t','fontsize',12,'fontweigh','bold')
zlabel('\it C_t','fontsize',12,'fontweigh','bold');
% title('Black-Schloes Call Option Price','Fontsize',14,'Fontweigh','bold')
% End of program
% -------------------------------------------------------------------------